@@ -37,13 +37,6 @@
 
 #include <toolkit/helper/vclunohelper.hxx>
 
-
-#include "misc.hxx"
-
-#ifdef STARIMAGE_AVAILABLE
-#include <sim2/simdll.hxx>
-#endif
-
 #include "strings.hrc"
 #include "ViewShell.hxx"
 #include "DrawViewShell.hxx"
@@ -148,12 +141,6 @@ void Client::ObjectAreaChanged()
     }
 }
 
-/*************************************************************************
-|*
-|*
-|*
-\************************************************************************/
-
 void Client::ViewChanged()
 {
     if ( GetAspect() == embed::Aspects::MSOLE_ICON )
