@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -42,7 +43,7 @@
 
 #include <tools/urlobj.hxx>
 #include <svl/urihelper.hxx>
-
+#include <sfx2/msgpool.hxx>
 #include <svtools/sores.hxx>
 #include <svtools/insdlg.hxx>
 #include <sfx2/request.hxx>
@@ -55,9 +56,7 @@
 #include <svx/linkwarn.hxx>
 #include <svx/svdetc.hxx>
 #include <avmedia/mediawindow.hxx>
-#ifndef _UNOTOOLS_UCBSTREAMHELPER_HXX
 #include <unotools/ucbstreamhelper.hxx>
-#endif
 #include <sfx2/printer.hxx>
 #include <sot/clsids.hxx>
 #include <svtools/sfxecode.hxx>
@@ -67,21 +66,16 @@
 #include <svx/svdograf.hxx>
 #include <svx/svdoole2.hxx>
 #include <svx/svdomedia.hxx>
-#ifndef _EDITENG_HXX //autogen
 #include <editeng/editeng.hxx>
-#endif
 #include <sot/storage.hxx>
 #include <sot/formats.hxx>
 #include <svx/svdpagv.hxx>
-#ifndef _MSGBOX_HXX //autogen
 #include <vcl/msgbox.hxx>
-#endif
 #include <sfx2/opengrf.hxx>
 
 #include <sfx2/viewfrm.hxx>
 
 #include "app.hrc"
-#include "misc.hxx"
 #include "sdresid.hxx"
 #include "View.hxx"
 #include "app.hxx"
@@ -175,7 +169,7 @@ void FuInsertGraphic::DoExecute( SfxRequest&  )
         }
         else
         {
-            SdGRFFilter::HandleGraphicFilterError( (USHORT)nError, GraphicFilter::GetGraphicFilter()->GetLastError().nStreamError );
+            SdGRFFilter::HandleGraphicFilterError( (sal_uInt16)nError, GraphicFilter::GetGraphicFilter()->GetLastError().nStreamError );
         }
     }
 }
@@ -210,7 +204,7 @@ FunctionReference FuInsertClipboard::Create( ViewShell* pViewSh, ::sd::Window* p
 void FuInsertClipboard::DoExecute( SfxRequest&  )
 {
     TransferableDataHelper						aDataHelper( TransferableDataHelper::CreateFromSystemClipboard( mpWindow ) );
-    ULONG                                       nFormatId;
+    sal_uLong                                       nFormatId;
 
     SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
     SfxAbstractPasteDialog* pDlg = pFact->CreatePasteDialog( mpViewShell->GetActiveWindow() );
@@ -239,7 +233,7 @@ void FuInsertClipboard::DoExecute( SfxRequest&  )
 
             if( !mpView->InsertData( aDataHelper,
                                     mpWindow->PixelToLogic( Rectangle( Point(), mpWindow->GetOutputSizePixel() ).Center() ),
-                                    nAction, FALSE, nFormatId ) &&
+                                    nAction, sal_False, nFormatId ) &&
                 ( mpViewShell && mpViewShell->ISA( DrawViewShell ) ) )
             {
                 DrawViewShell* pDrViewSh = static_cast<DrawViewShell*>(mpViewShell);
@@ -380,7 +374,7 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
 
             bool bRet = true;
             if( pPickObj )
-                mpView->ReplaceObjectAtView(pPickObj, *pPV, pOleObj, TRUE );
+                mpView->ReplaceObjectAtView(pPickObj, *pPV, pOleObj, sal_True );
             else
                 bRet = mpView->InsertObjectAtView(pOleObj, *pPV, SDRINSERT_SETDEFLAYER);
 
@@ -399,7 +393,6 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
                     pOleObj->SetProgName( UniString::CreateFromAscii( RTL_CONSTASCII_STRINGPARAM( "StarMath" ) ) );
                 }
 
-                //HMHmpView->HideMarkHdl();
                 pOleObj->SetLogicRect(aRect);
                 Size aTmp( OutputDevice::LogicToLogic( aRect.GetSize(), MAP_100TH_MM, aUnit ) );
                 awt::Size aVisualSize;
@@ -429,7 +422,7 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
         * Objekt einfuegen
         **********************************************************************/
         sal_Int64 nAspect = embed::Aspects::MSOLE_CONTENT;
-        BOOL bCreateNew = FALSE;
+        sal_Bool bCreateNew = sal_False;
         uno::Reference < embed::XEmbeddedObject > xObj;
         uno::Reference < embed::XStorage > xStorage = comphelper::OStorageHelper::GetTemporaryStorage();
         SvObjectServerList aServerLst;
@@ -464,12 +457,11 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
                     // intentionally no break!
                 }
                 case SID_INSERT_PLUGIN :
-                case SID_INSERT_APPLET :
                 case SID_INSERT_FLOATINGFRAME :
                 {
                     SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
                     SfxAbstractInsertObjectDialog* pDlg =
-                            pFact->CreateInsertObjectDialog( mpViewShell->GetActiveWindow(), nSlotId,
+                            pFact->CreateInsertObjectDialog( mpViewShell->GetActiveWindow(), SD_MOD()->GetSlotPool()->GetSlot(nSlotId)->GetCommandString(),
                             xStorage, &aServerLst );
                     if ( pDlg )
                     {
@@ -513,7 +505,7 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
                                 uno::Reference < beans::XPropertySet > xSet( xSup->getComponent(), uno::UNO_QUERY );
                                 if ( xSet.is() )
                                 {
-                                    xSet->setPropertyValue( ::rtl::OUString::createFromAscii("PluginURL"),
+                                    xSet->setPropertyValue( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("PluginURL")),
                                             uno::makeAny( ::rtl::OUString( aURL.GetMainURL( INetURLObject::NO_DECODE ) ) ) );
                                 }
                             }
@@ -538,9 +530,9 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
             {
                 //TODO/LATER: needs status for RESIZEONPRINTERCHANGE
                 //if( SVOBJ_MISCSTATUS_RESIZEONPRINTERCHANGE & xObj->getStatus( nAspect ) )
-                //    aIPObj->OnDocumentPrinterChanged( mpDocSh->GetPrinter(FALSE) );
+                //    aIPObj->OnDocumentPrinterChanged( mpDocSh->GetPrinter(sal_False) );
 
-                BOOL bInsertNewObject = TRUE;
+                sal_Bool bInsertNewObject = sal_True;
 
                 Size aSize;
                 MapUnit aMapUnit = MAP_100TH_MM;
@@ -595,8 +587,8 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
                                 /**************************************************
                                     * Das leere OLE-Objekt bekommt ein neues IPObj
                                     **************************************************/
-                                bInsertNewObject = FALSE;
-                                pObj->SetEmptyPresObj(FALSE);
+                                bInsertNewObject = sal_False;
+                                pObj->SetEmptyPresObj(sal_False);
                                 ( (SdrOle2Obj*) pObj)->SetOutlinerParaObject(NULL);
                                 ( (SdrOle2Obj*) pObj)->SetObjRef(xObj);
                                 ( (SdrOle2Obj*) pObj)->SetPersistName(aName);
@@ -604,8 +596,6 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
                                 ( (SdrOle2Obj*) pObj)->SetAspect(nAspect);
                                 Rectangle aRect = ( (SdrOle2Obj*) pObj)->GetLogicRect();
 
-                                //HMHmpView->HideMarkHdl();
-
                                 if ( nAspect == embed::Aspects::MSOLE_ICON )
                                 {
                                     if( xIconMetaFile.is() )
@@ -647,7 +637,7 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
 
                     if( mpView->InsertObjectAtView(pObj, *pPV, SDRINSERT_SETDEFLAYER) )
                     {
-                        //  #73279# Math objects change their object size during InsertObject.
+                        //  Math objects change their object size during InsertObject.
                         //  New size must be set in SdrObject, or a wrong scale will be set at
                         //  ActivateObject.
 
@@ -671,7 +661,6 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
 
                         if (bCreateNew)
                         {
-                            //HMHmpView->HideMarkHdl();
                             pObj->SetLogicRect(aRect);
 
                             if ( nAspect != embed::Aspects::MSOLE_ICON )
@@ -788,3 +777,5 @@ void FuInsertAVMedia::DoExecute( SfxRequest& rReq )
 }
 
 } // end of namespace sd
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
